@@ -3,10 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_vcnl4040
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()
 sensor = adafruit_vcnl4040.VCNL4040(i2c)
 
 while True:
